Description: fixes spelling errors reported by lintian info tag spelling-error-in-manpage
Author: Ryan Niebur <ryan@debian.org>

Index: storebackup/bin/llt
===================================================================
--- storebackup.orig/bin/llt	2012-06-16 03:02:41.000000000 -0700
+++ storebackup/bin/llt	2012-06-16 03:39:08.000000000 -0700
@@ -138,7 +138,7 @@
     parameter is the time since epoch
     llt print the date in a readable format
     this option can be repeated multiple times
-    llt will stop executing if no other options or params are choosen
+    llt will stop executing if no other options or params are chosen
 
 =back
 
Index: storebackup/bin/storeBackupDel.pl
===================================================================
--- storebackup.orig/bin/storeBackupDel.pl	2012-06-16 03:02:41.000000000 -0700
+++ storebackup/bin/storeBackupDel.pl	2012-06-16 03:39:08.000000000 -0700
@@ -177,7 +177,7 @@
 =item B<--keepWeekday>
 
 		    keep backups for the specified days for the specified
-		    amount of time. Overwrites the default values choosen in
+		    amount of time. Overwrites the default values chosen in
 		    --keepAll. 'Mon,Wed:40d Sat:60d10m' means:
 			keep backups of Mon and Wed 40days + 5mins
 			keep backups of Sat 60days + 10mins
Index: storebackup/bin/storeBackupUpdateBackup.pl
===================================================================
--- storebackup.orig/bin/storeBackupUpdateBackup.pl	2012-06-16 03:02:41.000000000 -0700
+++ storebackup/bin/storeBackupUpdateBackup.pl	2012-06-16 03:39:08.000000000 -0700
@@ -143,7 +143,7 @@
 
 =item B<--autorepair>, B<-a>
 
-    repair simple inconsistencies automaticly without
+    repair simple inconsistencies automatically without
     requesting the action
 
 =item B<--print>
@@ -170,7 +170,7 @@
 =item B<--noCompress>
 
     maximal number of parallel compress operations,
-    default = choosen automatically
+    default = chosen automatically
 
 =item B<--checkOnly> B<-c>
 
Index: storebackup/bin/storeBackupls.pl
===================================================================
--- storebackup.orig/bin/storeBackupls.pl	2012-06-16 03:02:41.000000000 -0700
+++ storebackup/bin/storeBackupls.pl	2012-06-16 03:39:08.000000000 -0700
@@ -122,7 +122,7 @@
 
 =item B<--verbose>, B<-v>
 
-    additional informations about the backup directories
+    additional information about the backup directories
 
 =item B<--print>
 

Index: storebackup/bin/storeBackup.pl
===================================================================
--- storebackup.orig/bin/storeBackup.pl	2012-06-16 03:02:41.000000000 -0700
+++ storebackup/bin/storeBackup.pl	2012-06-16 03:39:08.000000000 -0700
@@ -391,7 +391,7 @@
 
 =item B<--ignorePerms>
 
-    If this option choosen, files will not necessarily have
+    If this option chosen, files will not necessarily have
     the same permissions and owner as the originals. This
     speeds up backups on network drives a lot. Recovery with
     storeBackupRecover.pl will restore them correctly.
@@ -618,7 +618,7 @@
 =item B<--noCompress>
 
     maximal number of parallel compress operations,
-    default = choosen automatically
+    default = chosen automatically
 
 =item B<--queueCompress>
 
@@ -690,7 +690,7 @@
 =item B<--keepWeekday>
 
     keep backups for the specified days for the specified
-    amount of time. Overwrites the default values choosen in
+    amount of time. Overwrites the default values chosen in
     --keepAll. 'Mon,Wed:40d Sat:60d10m' means:
       keep backups from Mon and Wed 40days + 5mins
       keep backups from Sat 60days + 10mins
@@ -1330,7 +1330,7 @@
 ;comprRule=
 
 # maximal number of parallel compress operations,
-# default = choosen automatically
+# default = chosen automatically
 ;noCompress=
 
 # length of queue to store files before compression,
@@ -1398,7 +1398,7 @@
 ;keepAll=
 
 # keep backups for the specified days for the specified
 # amount of time. Overwrites the default values choosen in
 # --keepAll. 'Mon,Wed:40d Sat:60d10m' means:
 # keep backups from Mon and Wed 40days + 5mins
 # keep backups from Sat 60days + 10mins
@@ -1398,7 +1398,7 @@
 
 # keep backups for the specified days for the specified
-# amount of time. Overwrites the default values choosen in
+# amount of time. Overwrites the default values chosen in
 # --keepAll. 'Mon,Wed:40d Sat:60d10m' means:
 # keep backups from Mon and Wed 40days + 5mins
Index: storebackup/bin/storeBackupSearch.pl
===================================================================
--- storebackup.orig/bin/storeBackupSearch.pl	2012-06-16 03:02:41.000000000 -0700
+++ storebackup/bin/storeBackupSearch.pl	2012-06-16 03:39:08.000000000 -0700
@@ -154,7 +154,7 @@
 
 =item B<--parJobs>, B<-p>
 
-    number of parallel jobs, default = choosen automaticly
+    number of parallel jobs, default = chosen automatically
 
 =item B<--debug>, B<-d>
 
@@ -168,7 +168,7 @@
 
     Root directories of backups where to search relative
     to backupDir. If no directories are specified, all
-    backups below backupDir are choosen.
+    backups below backupDir are chosen.
 
 =back
 
@@ -232,7 +232,7 @@
 # write search result also to file
 ;writeToFile=
 
 # number of parallel jobs, default = choosen automaticly
 ;parJobs=
 
 # debug level, possible values are 0, 1, 2, default = 0
@@ -232,7 +232,7 @@
 ;writeToFile=
 
-# number of parallel jobs, default = choosen automaticly
+# number of parallel jobs, default = chosen automatically
 ;parJobs=
 